==> zio-aws-apigatewayv2_2.12-5.17.191.2-sources.jar: zio/aws/apigatewayv2/model/CreateRouteResponseResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.{
  __string,
  SelectionKey,
  SelectionExpression,
  StringWithLengthBetween1And128,
  Id
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateRouteResponseResponse(
    modelSelectionExpression: Optional[SelectionExpression] = Optional.Absent,
    responseModels: Optional[Map[__string, StringWithLengthBetween1And128]] =
      Optional.Absent,
    responseParameters: Optional[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints]
    ] = Optional.Absent,
    routeResponseId: Optional[Id] = Optional.Absent,
    routeResponseKey: Optional[SelectionKey] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.CreateRouteResponseResponse = {
    import CreateRouteResponseResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.CreateRouteResponseResponse
      .builder()
      .optionallyWith(
        modelSelectionExpression.map(value =>
          SelectionExpression.unwrap(value): java.lang.String
        )
      )(_.modelSelectionExpression)
      .optionallyWith(
        responseModels.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (StringWithLengthBetween1And128.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.responseModels)
      .optionallyWith(
        responseParameters.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> value.buildAwsValue()
            })
            .asJava
        )
      )(_.responseParameters)
      .optionallyWith(
        routeResponseId.map(value => Id.unwrap(value): java.lang.String)
      )(_.routeResponseId)
      .optionallyWith(
        routeResponseKey.map(value =>
          SelectionKey.unwrap(value): java.lang.String
        )
      )(_.routeResponseKey)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.CreateRouteResponseResponse.ReadOnly =
    zio.aws.apigatewayv2.model.CreateRouteResponseResponse.wrap(buildAwsValue())
}
object CreateRouteResponseResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.CreateRouteResponseResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.CreateRouteResponseResponse =
      zio.aws.apigatewayv2.model.CreateRouteResponseResponse(
        modelSelectionExpression.map(value => value),
        responseModels.map(value => value),
        responseParameters.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        routeResponseId.map(value => value),
        routeResponseKey.map(value => value)
      )
    def modelSelectionExpression: Optional[SelectionExpression]
    def responseModels: Optional[Map[__string, StringWithLengthBetween1And128]]
    def responseParameters: Optional[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly]
    ]
    def routeResponseId: Optional[Id]
    def routeResponseKey: Optional[SelectionKey]
    def getModelSelectionExpression: ZIO[Any, AwsError, SelectionExpression] =
      AwsError.unwrapOptionField(
        "modelSelectionExpression",
        modelSelectionExpression
      )
    def getResponseModels
        : ZIO[Any, AwsError, Map[__string, StringWithLengthBetween1And128]] =
      AwsError.unwrapOptionField("responseModels", responseModels)
    def getResponseParameters: ZIO[Any, AwsError, Map[
      __string,
      zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly
    ]] = AwsError.unwrapOptionField("responseParameters", responseParameters)
    def getRouteResponseId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("routeResponseId", routeResponseId)
    def getRouteResponseKey: ZIO[Any, AwsError, SelectionKey] =
      AwsError.unwrapOptionField("routeResponseKey", routeResponseKey)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.CreateRouteResponseResponse
  ) extends zio.aws.apigatewayv2.model.CreateRouteResponseResponse.ReadOnly {
    override val modelSelectionExpression: Optional[SelectionExpression] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modelSelectionExpression())
        .map(value =>
          zio.aws.apigatewayv2.model.primitives.SelectionExpression(value)
        )
    override val responseModels
        : Optional[Map[__string, StringWithLengthBetween1And128]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.responseModels())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: __string) -> zio.aws.apigatewayv2.model.primitives
                .StringWithLengthBetween1And128(value)
            })
            .toMap
        )
    override val responseParameters: Optional[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.responseParameters())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: __string) -> zio.aws.apigatewayv2.model.ParameterConstraints
              .wrap(value)
          })
          .toMap
      )
    override val routeResponseId: Optional[Id] = zio.aws.core.internal
      .optionalFromNullable(impl.routeResponseId())
      .map(value => zio.aws.apigatewayv2.model.primitives.Id(value))
    override val routeResponseKey: Optional[SelectionKey] =
      zio.aws.core.internal
        .optionalFromNullable(impl.routeResponseKey())
        .map(value => zio.aws.apigatewayv2.model.primitives.SelectionKey(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.CreateRouteResponseResponse
  ): zio.aws.apigatewayv2.model.CreateRouteResponseResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.13-5.17.126.2-sources.jar: zio/aws/apigatewayv2/model/CreateRouteResponseResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.{
  __string,
  SelectionKey,
  SelectionExpression,
  StringWithLengthBetween1And128,
  Id
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateRouteResponseResponse(
    modelSelectionExpression: Option[SelectionExpression] = None,
    responseModels: Option[Map[__string, StringWithLengthBetween1And128]] =
      None,
    responseParameters: Option[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints]
    ] = None,
    routeResponseId: Option[Id] = None,
    routeResponseKey: Option[SelectionKey] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.CreateRouteResponseResponse = {
    import CreateRouteResponseResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.CreateRouteResponseResponse
      .builder()
      .optionallyWith(
        modelSelectionExpression.map(value =>
          SelectionExpression.unwrap(value): java.lang.String
        )
      )(_.modelSelectionExpression)
      .optionallyWith(
        responseModels.map(value =>
          value
            .map({ case (key, value) =>
              (__string.unwrap(
                key
              ): java.lang.String) -> (StringWithLengthBetween1And128.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.responseModels)
      .optionallyWith(
        responseParameters.map(value =>
          value
            .map({ case (key, value) =>
              (__string.unwrap(key): java.lang.String) -> value.buildAwsValue()
            })
            .asJava
        )
      )(_.responseParameters)
      .optionallyWith(
        routeResponseId.map(value => Id.unwrap(value): java.lang.String)
      )(_.routeResponseId)
      .optionallyWith(
        routeResponseKey.map(value =>
          SelectionKey.unwrap(value): java.lang.String
        )
      )(_.routeResponseKey)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.CreateRouteResponseResponse.ReadOnly =
    zio.aws.apigatewayv2.model.CreateRouteResponseResponse.wrap(buildAwsValue())
}
object CreateRouteResponseResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.CreateRouteResponseResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.CreateRouteResponseResponse =
      zio.aws.apigatewayv2.model.CreateRouteResponseResponse(
        modelSelectionExpression.map(value => value),
        responseModels.map(value => value),
        responseParameters.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        routeResponseId.map(value => value),
        routeResponseKey.map(value => value)
      )
    def modelSelectionExpression: Option[SelectionExpression]
    def responseModels: Option[Map[__string, StringWithLengthBetween1And128]]
    def responseParameters: Option[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly]
    ]
    def routeResponseId: Option[Id]
    def routeResponseKey: Option[SelectionKey]
    def getModelSelectionExpression: ZIO[Any, AwsError, SelectionExpression] =
      AwsError.unwrapOptionField(
        "modelSelectionExpression",
        modelSelectionExpression
      )
    def getResponseModels
        : ZIO[Any, AwsError, Map[__string, StringWithLengthBetween1And128]] =
      AwsError.unwrapOptionField("responseModels", responseModels)
    def getResponseParameters: ZIO[Any, AwsError, Map[
      __string,
      zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly
    ]] = AwsError.unwrapOptionField("responseParameters", responseParameters)
    def getRouteResponseId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("routeResponseId", routeResponseId)
    def getRouteResponseKey: ZIO[Any, AwsError, SelectionKey] =
      AwsError.unwrapOptionField("routeResponseKey", routeResponseKey)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.CreateRouteResponseResponse
  ) extends zio.aws.apigatewayv2.model.CreateRouteResponseResponse.ReadOnly {
    override val modelSelectionExpression: Option[SelectionExpression] = scala
      .Option(impl.modelSelectionExpression())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives.SelectionExpression(value)
      )
    override val responseModels
        : Option[Map[__string, StringWithLengthBetween1And128]] = scala
      .Option(impl.responseModels())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.apigatewayv2.model.primitives
              .__string(key) -> zio.aws.apigatewayv2.model.primitives
              .StringWithLengthBetween1And128(value)
          })
          .toMap
      )
    override val responseParameters: Option[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly]
    ] = scala
      .Option(impl.responseParameters())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.apigatewayv2.model.primitives.__string(
              key
            ) -> zio.aws.apigatewayv2.model.ParameterConstraints.wrap(value)
          })
          .toMap
      )
    override val routeResponseId: Option[Id] = scala
      .Option(impl.routeResponseId())
      .map(value => zio.aws.apigatewayv2.model.primitives.Id(value))
    override val routeResponseKey: Option[SelectionKey] = scala
      .Option(impl.routeResponseKey())
      .map(value => zio.aws.apigatewayv2.model.primitives.SelectionKey(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.CreateRouteResponseResponse
  ): zio.aws.apigatewayv2.model.CreateRouteResponseResponse.ReadOnly =
    new Wrapper(impl)
}
